--[[
FamilyFighter_Tacker.lua
@Author  : Culicidae
@Link    : https://wow.curseforge.com/projects/family-fighter-tracker
]]

local ACHIEVEMENTS = {
    { id = 12089, type = 9,  },
    { id = 12091, type = 8,  },
    { id = 12092, type = 5,  },
    { id = 12093, type = 2,  },
    { id = 12094, type = 7,  },
    { id = 12095, type = 3,  },
    { id = 12096, type = 1,  },
    { id = 12097, type = 6,  },
    { id = 12098, type = 10, },
    { id = 12099, type = 4,  },
}

local NPCS = {
    ['128007'] = true,
    ['128009'] = true,
    ['128011'] = true,
    ['128013'] = true,
    ['128015'] = true,
    ['128017'] = true,
    ['128019'] = true,
    ['128021'] = true,
    ['128023'] = true,
    ['128008'] = true,
    ['128010'] = true,
    ['128012'] = true,
    ['128014'] = true,
    ['128016'] = true,
    ['128018'] = true,
    ['128020'] = true,
    ['128022'] = true,
    ['128024'] = true,
}

local function isFinished(id, name)
    for i = 1, GetAchievementNumCriteria(id) do
        local criteriaString, _, completed = GetAchievementCriteriaInfo(id, i)
        if criteriaString == name then
            return completed
        end
    end
    return true
end

local function getUnFinished(npcId, npcName)
    local list = {}
    for _, v in ipairs(ACHIEVEMENTS) do
        if not isFinished(v.id, npcName) then
            tinsert(list, v)
        end
    end
    return list
end

local function getFinished(npcId, npcName)
    local list = {}
    for _, v in ipairs(ACHIEVEMENTS) do
        if isFinished(v.id, npcName) then
            tinsert(list, v)
        end
    end
    return list
end

GameTooltip:HookScript('OnTooltipSetUnit', function(self, ...)
    local guid = UnitGUID('mouseover')
    if not guid then
        return
    end
    local npcId = guid:match('.-%-%d+%-%d+%-%d+%-%d+%-(%d+)')
    if not NPCS[npcId] then
        return
    end

    local unfinished = getUnFinished(npcId, UnitName('mouseover'))
    local finished = getFinished(npcId, UnitName('mouseover'))
    if not #unfinished == 0 then
        return
    end

    GameTooltip:AddLine(' ')
    GameTooltip:AddLine(select(2, GetAchievementInfo(12100)), NORMAL_FONT_COLOR:GetRGB())
    for _, v in ipairs(unfinished) do
        GameTooltip:AddLine(format([[|TInterface\TARGETINGFRAME\PetBadge-%s:16|t %s]], PET_TYPE_SUFFIX[v.type], select(2, GetAchievementInfo(v.id))), RED_FONT_COLOR:GetRGB())
    end

    for _, v in ipairs(finished) do
        GameTooltip:AddLine(format([[|TInterface\TARGETINGFRAME\PetBadge-%s:16|t %s]], PET_TYPE_SUFFIX[v.type], select(2, GetAchievementInfo(v.id))), GREEN_FONT_COLOR:GetRGB())
    end
    GameTooltip:Show()
end)
